@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -108,10 +108,25 @@ function api_networks_cancel($network_id){
 function api_networks_discover($network_id) {
 	global $config;
 
-	$enabled   = db_fetch_cell_prepared('SELECT enabled FROM automation_networks WHERE id = ?', array($network_id));
-	$running   = db_fetch_cell_prepared('SELECT count(*) FROM automation_processes WHERE network_id = ?', array($network_id));
-	$name      = db_fetch_cell_prepared('SELECT name FROM automation_networks WHERE id = ?', array($network_id));
-	$poller_id = db_fetch_cell_prepared('SELECT poller_id FROM automation_networks WHERE id = ?', array($network_id));
+	$enabled   = db_fetch_cell_prepared('SELECT enabled
+		FROM automation_networks
+		WHERE id = ?',
+		array($network_id));
+
+	$running = db_fetch_cell_prepared('SELECT count(*)
+		FROM automation_processes
+		WHERE network_id = ?',
+		array($network_id));
+
+	$name = db_fetch_cell_prepared('SELECT name
+		FROM automation_networks
+		WHERE id = ?',
+		array($network_id));
+
+	$poller_id = db_fetch_cell_prepared('SELECT poller_id
+		FROM automation_networks
+		WHERE id = ?',
+		array($network_id));
 
 	if ($enabled == 'on') {
 		if (!$running) {
@@ -124,8 +139,9 @@ function api_networks_discover($network_id) {
 					array($poller_id));
 
 				$fgc_contextoption = get_default_contextoption();
-				if($fgc_contextoption) {
+				if ($fgc_contextoption) {
 					$fgc_context = stream_context_create($fgc_contextoption);
+
 					$response = file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=discover&network=' . $network_id, false, $fgc_context);
 				} else {
 					$response = file_get_contents(get_url_type() .'://' . $hostname . $config['url_path'] . 'remote_agent.php?action=discover&network=' . $network_id);
@@ -911,6 +927,10 @@ function networks() {
 			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
+		'refresh' => array(
+			'filter' => FILTER_VALIDATE_INT,
+			'default' => '20'
+			),
 		'filter' => array(
 			'filter' => FILTER_CALLBACK,
 			'pageset' => true,
@@ -932,6 +952,12 @@ function networks() {
 	validate_store_request_vars($filters, 'sess_networks');
 	/* ================= input validation ================= */
 
+	$refresh['page']    = 'automation_networks.php?header=false';
+	$refresh['seconds'] = get_request_var('refresh');
+	$refresh['logout']  = 'false';
+
+	set_page_refresh($refresh);
+
 	if (get_request_var('rows') == -1) {
 		$rows = read_config_option('num_rows_table');
 	} elseif (get_request_var('rows') == -2) {
@@ -1088,6 +1114,28 @@ function networks_filter() {
 							?>
 						</select>
 					</td>
+					<td>
+						<?php print __('Refresh');?>
+					</td>
+					<td>
+						<select id='refresh' onChange='applyFilter()'>
+							<?php
+							$frequency = array(
+								10  => __('%d Seconds', 10),
+								20  => __('%d Seconds', 20),
+								30  => __('%d Seconds', 30),
+								45  => __('%d Seconds', 45),
+								60  => __('%d Minute', 1),
+								120 => __('%d Minutes', 2),
+								300 => __('%d Minutes', 5)
+							);
+
+							foreach ($frequency as $r => $row) {
+								echo "<option value='" . $r . "'" . (isset_request_var('refresh') && $r == get_request_var('refresh') ? ' selected' : '') . '>' . $row . '</option>';
+							}
+							?>
+						</select>
+					</td>
 					<td>
 						<span>
 							<input type='button' id='go' title='<?php print __esc('Search');?>' value='<?php print __esc('Go');?>'>
@@ -1101,6 +1149,7 @@ function networks_filter() {
 			function applyFilter() {
 				strURL  = '?rows=' + $('#rows').val();
 				strURL += '&filter=' + $('#filter').val();
+				strURL += '&refresh=' + $('#refresh').val();
 				strURL += '&header=false';
 
 				loadPageNoHeader(strURL);
