@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -14,7 +14,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -52,7 +52,7 @@ if (sizeof($parms)) {
 	$site_id       = 0;
 	$template_id   = 0;
 	$community     = read_config_option('snmp_community');
-	$snmp_ver      = read_config_option('snmp_ver');
+	$snmp_ver      = read_config_option('snmp_version');
 	$disable       = 0;
 
 	$notes         = '';
@@ -77,9 +77,9 @@ if (sizeof($parms)) {
 	$proxy          = false;
 	$device_threads = read_config_option('device_threads');;
 
-	$displayHostTemplates = FALSE;
-	$displayCommunities   = FALSE;
-	$quietMode            = FALSE;
+	$displayHostTemplates = false;
+	$displayCommunities   = false;
+	$quietMode            = false;
 
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
@@ -91,7 +91,7 @@ if (sizeof($parms)) {
 
 		switch ($arg) {
 		case '-d':
-			$debug = TRUE;
+			$debug = true;
 
 			break;
 		case '--description':
@@ -274,15 +274,15 @@ if (sizeof($parms)) {
 			display_help();
 			exit;
 		case '--list-communities':
-			$displayCommunities = TRUE;
+			$displayCommunities = true;
 
 			break;
 		case '--list-host-templates':
-			$displayHostTemplates = TRUE;
+			$displayHostTemplates = true;
 
 			break;
 		case '--quiet':
-			$quietMode = TRUE;
+			$quietMode = true;
 
 			break;
 		default:
@@ -332,12 +332,14 @@ if (sizeof($parms)) {
 
 	/* process ip */
 	if (isset($addresses[$ip])) {
-		$id = $addresses[$ip];
+		$id    = $addresses[$ip];
 		$phost = db_fetch_row_prepared('SELECT * FROM host WHERE id = ?', array($id));
-		$fail = false;
+		$fail  = false;
 
 		if ($phost['snmp_version'] < '3' && $snmp_ver < '3') {
-			if ($phost['snmp_community'] != $community) {
+			if ($snmp_ver == 0 && $proxy) {
+				// proxy but for no snmp
+			} elseif ($phost['snmp_community'] != $community) {
 				if ($proxy) {
 					// assuming an snmp-proxy
 				} else {
@@ -351,7 +353,7 @@ if (sizeof($parms)) {
 			// assumeing a proxy
 		} elseif ($phost['snmp_version'] == '3' && $snmp_ver == '3') {
 			$changed = 0;
-			$changed += ($phost['snmp_usernanem'] != $username ? 1:0);
+			$changed += ($phost['snmp_username'] != $username ? 1:0);
 			$changed += ($phost['snmp_context'] != $snmp_context ? 1:0);
 			$changed += ($phost['snmp_engine_id'] != $snmp_engine_id ? 1:0);
 			$changed += ($phost['snmp_auth_protocol'] != $snmp_auth_protocol ? 1:0);
