@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -421,7 +421,7 @@ function form_actions() {
 
 	form_start('data_sources.php');
 
-	html_start_box($ds_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($ds_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
 	if (isset($ds_array) && sizeof($ds_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
@@ -697,7 +697,7 @@ function ds_edit() {
 				AND local_data_id = 0',
 				array($data_local['data_template_id']));
 		} else {
-			$_SESSION['sess_messages'] = __('Data Source %d does not exist.', get_request_var('id'));
+			raise_message(11);
 			header ('Location: data_sources.php');
 			exit;
 		}
@@ -886,14 +886,14 @@ function ds_edit() {
 			$form_array += array($field_name => $struct_data_source[$field_name]);
 
 			if (($field_array['method'] != 'header') && ($field_array['method'] != 'spacer' )){
-				if (!(($use_data_template == false) || (!empty($data_template_data{'t_' . $field_name})) || ($field_array['flags'] == 'NOTEMPLATE'))) {
+				if (!(($use_data_template == false) || (!empty($data_template_data['t_' . $field_name])) || ($field_array['flags'] == 'NOTEMPLATE'))) {
 					$form_array[$field_name]['description'] = '';
 				}
 
 				$form_array[$field_name]['value'] = (isset($data[$field_name]) ? $data[$field_name] : '');
 				$form_array[$field_name]['form_id'] = (empty($data['id']) ? '0' : $data['id']);
 
-				if (!(($use_data_template == false) || (!empty($data_template_data{'t_' . $field_name})) || ($field_array['flags'] == 'NOTEMPLATE'))) {
+				if (!(($use_data_template == false) || (!empty($data_template_data['t_' . $field_name])) || ($field_array['flags'] == 'NOTEMPLATE'))) {
 					$form_array[$field_name]['method'] = 'template_' . $form_array[$field_name]['method'];
 				}
 			}
@@ -974,13 +974,13 @@ function ds_edit() {
 			$form_array += array($field_name => $struct_data_source_item[$field_name]);
 
 			if (($field_array['method'] != 'header') && ($field_array['method'] != 'spacer' )){
-				if (!(($use_data_template == false) || ($rrd_template{'t_' . $field_name} == 'on'))) {
+				if (!(($use_data_template == false) || ($rrd_template['t_' . $field_name] == 'on'))) {
 					$form_array[$field_name]['description'] = '';
 				}
 
 				$form_array[$field_name]['value'] = (isset($rrd) ? $rrd[$field_name] : '');
 
-				if (!(($use_data_template == false) || ($rrd_template{'t_' . $field_name} == 'on'))) {
+				if (!(($use_data_template == false) || ($rrd_template['t_' . $field_name] == 'on'))) {
 					$form_array[$field_name]['method'] = 'template_' . $form_array[$field_name]['method'];
 				}
 			}
