@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -29,7 +29,32 @@
    @arg $cell_padding - the amount of cell padding to use inside of the box
    @arg $align - the HTML alignment to use for the box (center, left, or right)
    @arg $add_text - the url to use when the user clicks 'Add' in the upper-right
-     corner of the box ("" for no 'Add' link) */
+     corner of the box ("" for no 'Add' link)
+     This function has two method.  This first is for legacy behavior where you
+     you pass in a href to the function, and an optional label as $add_label
+     The new format accepts an array of hrefs to add to the start box.  The format
+     of the array is as follows:
+
+     $add_text = array(
+        array(
+          'id' => 'uniqueid',
+          'href' => 'value',
+          'title' => 'title',
+          'callback' => true|false,
+          'class' => 'fa fa-icon'
+        ),
+        ...
+     );
+
+     If the callback is true, the Cacti attribute will be added to the href
+     to present only the contents and not to include both the headers.  If
+     the link must go off page, simply make sure $callback is false.  There
+     is a requirement to use fontawesome icon sets for this class, but it
+     can include other classes.  In addition, the href can be a hash '#' if
+     your page has a ready function that has it's own javascript.
+   @arg $add_label - used with legacy behavior to add specific text to the link.
+     This parameter is only used in the legacy behavior.
+ */
 function html_start_box($title, $width, $div, $cell_padding, $align, $add_text, $add_label = false) {
 	static $table_suffix = 1;
 
@@ -51,8 +76,45 @@ function html_start_box($title, $width, $div, $cell_padding, $align, $add_text,
 		print "<div id='$table_id' class='cactiTable' style='width:$width;text-align:$align;'>";
 		print "<div>";
 		print "<div class='cactiTableTitle'><span>" . ($title != '' ? $title:'') . '</span></div>';
-		print "<div class='cactiTableButton'><span>" . ($add_text != '' ? "<a class='linkOverDark' href='" . html_escape($add_text) . "'>" . $add_label . '</a>':'') . '</span></div>';
-		print '</div>';
+		print "<div class='cactiTableButton'>\n";
+		if ($add_text != '' && !is_array($add_text)) {
+			print "<span><a class='linkOverDark' title='$add_label' href='" . html_escape($add_text) . "'><i class='fa fa-plus'></i></a></span>";
+		} else {
+			if (is_array($add_text)) {
+				if (sizeof($add_text)) {
+					foreach($add_text as $icon) {
+						if (isset($icon['callback']) && $icon['callback'] === true) {
+							$classo = 'linkOverDark';
+						} else {
+							$classo = '';
+						}
+
+						if (isset($icon['class']) && $icon['class'] !== '') {
+							$classi = $icon['class'];
+						} else {
+							$classi = 'fa fa-plus';
+						}
+
+						if (isset($icon['href'])) {
+							$href = html_escape($icon['href']);
+						} else {
+							$href = '#';
+						}
+
+						if (isset($icon['title'])) {
+							$title = $icon['title'];
+						} else {
+							$title = $add_label;
+						}
+
+						print "<span><a" . (isset($icon['id']) ? "id='" . $icon['id'] . "'":"") . " class='$classo' href='$href' title='$title'><i class='$classi'></i></a></span>";
+					}
+				}
+			} else {
+				print "<span> </span>";
+			}
+		}
+		print '</div></div>';
 
 		if ($div === true) {
 			print "<div id='$table_id" . "_child' class='cactiTable'>";
@@ -1225,18 +1287,32 @@ function draw_actions_dropdown($actions_array, $delete_action = 1) {
 			});
 		}
 
-		$('tr[id^="line"]').not('.disabled_row').find('td').not('.checkbox').each(function(data) {
-			$(this).unbind().click(function(data) {
-				$(this).closest('tr').toggleClass('selected');
-				var checkbox = $(this).parent().find(':checkbox');
-				checkbox.prop('checked', !checkbox.is(':checked'));
+		var lines = $('tr[id^="line"]');
+		var checkboxes = lines.find('input.checkbox');
+
+		lines.filter(':not(.disabled_row)').find('td').not('.checkbox').each(function(data) {
+			$(this).unbind().click(function(e) {
+				if (e.shiftKey) {
+					updateCheckboxes(checkboxes, $(this).closest('tr').find(':checkbox'));
+				} else {
+					var checked = $(this).closest('tr').find(':checkbox').is(':checked');
+					$(this).closest('tr').siblings().find(':checkbox').removeAttr('data-prev-check');
+					$(this).closest('tr').toggleClass('selected').find(':checkbox').prop('checked', !checked)
+						.attr('data-prev-check', !checked);
+				}
 			});
 		});
 
-		$('tr[id^="line"]').find('input.checkbox').each(function(data) {
-			$(this).unbind().click(function(data) {
+		lines.find('input.checkbox').each(function(data) {
+			$(this).unbind().click(function(e) {
 				if (!$(this).closest('tr').hasClass('disabled_row')) {
-					$(this).closest('tr').toggleClass('selected');
+					if (e.shiftKey) {
+						updateCheckboxes(checkboxes, this);
+					} else {
+						$(this).closest('tr').toggleClass('selected');
+						$(this).closest('tr').siblings().find(':checkbox').removeAttr('data-prev-check');
+						$(this).attr('data-prev-check', $(this).prop('checked'));
+					}
 				}
 			});
 		});
