@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -118,7 +118,7 @@ function grow_dhtml_trees() {
 		$default_tree_id = db_fetch_cell('SELECT id FROM graph_tree ORDER BY sequence LIMIT 1');
 	}
 
-	print "<div style='white-space:nowrap'><span style='padding-right:4px;'>" . __('Search') . "</span><input id='searcher' style='padding:2px;font-size:12px;max-width:200px;' type='text' size='35'><hr></div>\n";
+	print "<div class='cactiTreeSearch' style='white-space:nowrap'><span style='padding-right:4px;'>" . __('Search') . "</span><input id='searcher' style='padding:2px;font-size:12px;max-width:200px;' type='text' size='35'><hr></div>\n";
 
 	$dhtml_tree = create_dhtml_tree();
 	if (sizeof($dhtml_tree)) {
@@ -139,36 +139,45 @@ function grow_dhtml_trees() {
 	var search_to = false;
 
 	function resizeGraphContent() {
-		if ('<?php print get_selected_theme();?>' != 'classic') {
-			$('.cactiGraphContentArea').css('margin-left', parseInt($('#navigation').width()+10)+'px');
-		} else {
-			width = $(document).width() - $('.cactiTreeNavigationArea').width() - 22;
-			$('.cactiGraphContentArea').css('width', width).css('float', 'right');
+		docHeight  = parseInt($('body').height());
+		navigation = $('.cactiTreeNavigationArea').offset();
+		navHeight  = docHeight - navigation.top + 15;
+		visWidth   = Math.max.apply(Math, $('.jstree').children(':visible').map(function() { return $(this).width(); }).get());
+		$('.cactiTreeNavigationArea').height(navHeight).width(visWidth);
+		$('.cactiGraphContentArea').css('margin-left', visWidth+10);
+	}
+
+	function checkTreeForLogout() {
+		html = $('#jstree').html();
+		found = html.indexOf('<?php print __('Login to Cacti');?>');
+		if (found >= 0) {
+			document.location = 'logout.php';
 		}
 	}
 
 	$(function () {
-		resizeGraphContent();
-
 		$('#jstree').each(function(data) {
 			var id=$(this).attr('id');
 
 			$(this)
-			.on('init.jstree', function(e, data) {
+			.on('init.jstree', function() {
 				<?php if (isset_request_var('hyper')) { ?>
 				//$('#jstree').jstree().clear_state();
 				<?php } ?>
 			})
-			.on('ready.jstree', function(e, data) {
+			.on('ready.jstree', function() {
 				resizeGraphContent();
 			})
-			.on('changed.jstree', function(e, data) {
+			.on('changed.jstree', function() {
 				resizeGraphContent();
 			})
-			.on('open_node.jstree', function(e, data) {
+			.on('before_open.jstree', function() {
+				checkTreeForLogout();
+			})
+			.on('open_node.jstree', function() {
 				resizeGraphContent();
 			})
-			.on('close_node.jstree', function(e, data) {
+			.on('close_node.jstree', function() {
 				resizeGraphContent();
 			})
 			.on('select_node.jstree', function(e, data) {
@@ -184,10 +193,14 @@ function grow_dhtml_trees() {
 
 					if (typeof href !== 'undefined') {
 						href=href.replace('action=tree', 'action=tree_content');
+						$('.cactiGraphContentArea').hide();
 
 						$.get(href, function(data) {
 							$('#main').html(data);
 							applySkin();
+
+							$('.cactiGraphContentArea').show();
+
 							var mytitle = 'Tree Mode - '+$('#nav_title').text();
 							document.getElementsByTagName('title')[0].innerHTML = mytitle;
 							if (typeof window.history.pushState !== 'undefined') {
@@ -255,22 +268,13 @@ function grow_dhtml_trees() {
 			}, 250);
 		});
 
-		$(window).resize(function() {
-			treeHeight = parseInt($(window).height()-$('.jstree').offset().top-10);
-			windHeight = parseInt($('.cactiContent').height());
-			docHeight  = parseInt($('body').height());
-
-			if (treeHeight > windHeight) {
-				$('#navigation').height(treeHeight+'px');
-			}else if (docHeight < windHeight) {
-				$('#navigation').height(docHeight+'px');
-			}else {
-				$('#navigation').height(windHeight+'px');
-			}
+		$(document).resize(function() {
+			resizeGraphContent();
 		});
 
 		<?php print api_plugin_hook_function('top_graph_jquery_function');?>
 	});
+
 	</script>
 	<?php
 }
@@ -337,12 +341,12 @@ function get_tree_path() {
 	}
 }
 
-function draw_dhtml_tree_level($tree_id, $parent = 0) {
+function draw_dhtml_tree_level($tree_id, $parent = 0, $editing = false) {
 	$dhtml_tree = array();
 
-	$heirarchy = get_allowed_tree_level($tree_id, $parent);
+	$heirarchy = get_allowed_tree_level($tree_id, $parent, $editing);
 
-	if (sizeof($heirarchy) > 0) {
+	if (sizeof($heirarchy)) {
 		$dhtml_tree[] = "\t\t\t<ul>\n";
 		foreach ($heirarchy as $leaf) {
 			if ($leaf['host_id'] > 0) {  //It's a host
@@ -1038,7 +1042,7 @@ function grow_right_pane_tree($tree_id, $leaf_id, $host_group_data) {
 						usort($graphs, 'naturally_sort_graphs');
 
 						foreach ($graphs as $graph) {
-							$snmp_index_to_graph{$graph['snmp_index']}{$graph['local_graph_id']} = $graph['title_cache'];
+							$snmp_index_to_graph[$graph['snmp_index']][$graph['local_graph_id']] = $graph['title_cache'];
 							$graphs_height[$graph['local_graph_id']] = $graph['height'];
 							$graphs_width[$graph['local_graph_id']] = $graph['width'];
 						}
