@@ -1,7 +1,7 @@
 <?php
 /*
    +-------------------------------------------------------------------------+
-   | Copyright (C) 2004-2017 The Cacti Group                                 |
+   | Copyright (C) 2004-2018 The Cacti Group                                 |
    |                                                                         |
    | This program is free software; you can redistribute it and/or           |
    | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
    | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
    | GNU General Public License for more details.                            |
    +-------------------------------------------------------------------------+
-   | Cacti: The Complete RRDTool-based Graphing Solution                     |
+   | Cacti: The Complete RRDtool-based Graphing Solution                     |
    +-------------------------------------------------------------------------+
    | This code is designed, written, and maintained by the Cacti Group. See  |
    | about.php and/or the AUTHORS file for specific developer information.   |
@@ -23,12 +23,12 @@
 */
 
 class MibCache{
-	private $active_mib				= '';
-	private $active_object			= '';
-	private $active_table			= '';
-	private $active_table_entry 	= '';
-	private $cache__tables			= array();
-	private $cache__tables_columns 	= array();
+	private $active_mib            = '';
+	private $active_object         = '';
+	private $active_table          = '';
+	private $active_table_entry    = '';
+	private $cache__tables         = array();
+	private $cache__tables_columns = array();
 
 	public function __construct($mib='CACTI-MIB') {
 		$this->active_mib = $mib;
@@ -53,6 +53,7 @@ class MibCache{
 
 	public function install($path, $replace=false, $mib_name='optional') {
 		global $config;
+
 		include_once($config['library_path'] . '/mib_parser.php');
 
 		$mp = new MibParser();
@@ -83,11 +84,11 @@ class MibCache{
 							str_replace("\r\n", '<br>', trim($object_params['description']))));
 
 					if ($object_params['otype'] == 'NOTIFICATION-TYPE') {
-						foreach($object_params['objects'] as $notication_object_index => $notication_object) {
+						foreach($object_params['objects'] as $notification_object_index => $notification_object) {
 							db_execute_prepared('INSERT INTO `snmpagent_cache_notifications` 
 								(`name`, `mib`, `attribute`, `sequence_id`) 
 								VALUES (?, ?, ?, ?)',
-								array($object_name, $object_params['mib'], $notication_object, $notication_object_index));
+								array($object_name, $object_params['mib'], $notification_object, $notification_object_index));
 						}
 					}
 				}else {
@@ -139,7 +140,7 @@ class MibCache{
 					/* MIB table does not exist */
 					$this->active_table = '';
 					$this->active_table_entry = '';
-					return 'ERROR';
+					throw new Exception('MIB table does not exist');
 				}
 			}else {
 				/* table exists and has already been cached */
@@ -182,7 +183,7 @@ class MibCache{
 	}
 
 	public function count() {
-		return db_execute_prepared('UPDATE LOW_PRIORITY snmpagent_cache
+		return db_execute_prepared('UPDATE IGNORE snmpagent_cache
 			SET `value` = CASE
 			WHEN `type`="Counter32" AND `value`= 4294967295 THEN 0
 			WHEN `type`="Counter64" AND `value`= 18446744073709551615 THEN 0
@@ -360,13 +361,13 @@ class MibCache{
 				foreach($columns as $column_params) {
 					$column_params['oid'] .= '.' . $this->active_table_entry;
 					if (isset($values[$column_params['name']])) {
-						$sql[] = '(' . db_qstr($values[$column_params['name']]) . ', ' . db_qstr($column_params['oid']) . ')';
+						$sql[] = '(' . db_qstr($column_params['name']) . ', ' . db_qstr($values[$column_params['name']]) . ', ' . db_qstr($column_params['oid']) . ')';
 					}
 				}
 
 				if (sizeof($sql)) {
 					db_execute('INSERT INTO `snmpagent_cache` 
-						(value, oid) 
+						(name, value, oid) 
 						VALUES ' . implode(', ', $sql) . '
 						ON DUPLICATE KEY UPDATE value=VALUES(value)', $sql);
 				}
@@ -374,6 +375,7 @@ class MibCache{
 				return true;
 			}
 		}
+
 		return false;
 	}
 
