@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2011 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  | Portions Copyright (C) 2010 Boris Lytochkin, Sponsored by Yandex LLC    |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
@@ -85,7 +85,13 @@ function cacti_snmp_session($hostname, $community, $version, $username, $passwor
 	}
 
 	if ($priv_proto == '[None]') {
-		$sec_level = 'authNoPriv';
+		if ($password == '') {
+			$sec_level   = 'noAuthNoPriv';
+			$sec_details = '';
+		} else {
+			$sec_level   = 'authNoPriv';
+			$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+		}
 		$priv_proto = '';
 	} else {
 		$sec_level = 'authPriv';
@@ -107,7 +113,8 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 
 	global $config, $snmp_error;
 
-	$max_oids = 1;
+	$max_oids   = 1;
+	$snmp_error = '';
 
 	if (!cacti_snmp_options_sanitize($version, $community, $port, $timeout, $retries, $max_oids)) {
 		return 'U';
@@ -128,7 +135,13 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 			$snmp_value = snmp2_get($hostname . ':' . $port, $community, $oid, ($timeout * 1000), $retries);
 		} else {
 			if ($priv_proto == '[None]' || $priv_pass == '') {
-				$sec_level = 'authNoPriv';
+				if ($password == '') {
+					$sec_level   = 'noAuthNoPriv';
+					$sec_details = '';
+				} else {
+					$sec_level   = 'authNoPriv';
+					$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+				}
 				$priv_proto = '';
 			} else {
 				$sec_level = 'authPriv';
@@ -156,7 +169,13 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 			$version = '2c'; /* ucd/net snmp prefers this over '2' */
 		} elseif ($version == '3') {
 			if ($priv_proto == '[None]' || $priv_pass == '') {
-				$sec_level = 'authNoPriv';
+				if ($password == '') {
+					$sec_level   = 'noAuthNoPriv';
+					$sec_details = '';
+				} else {
+					$sec_level   = 'authNoPriv';
+					$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+				}
 				$priv_proto = '';
 			} else {
 				$sec_level = 'authPriv';
@@ -182,8 +201,7 @@ function cacti_snmp_get($hostname, $community, $oid, $version, $username, $passw
 
 			$snmp_auth = trim('-u ' . snmp_escape_string($username) .
 				' -l ' . snmp_escape_string($sec_level) .
-				' -a ' . snmp_escape_string($auth_proto) .
-				' -A ' . snmp_escape_string($password) .
+				' '    . $sec_details .
 				' '    . $priv_pass .
 				' '    . $context .
 				' '    . $engineid);
@@ -223,7 +241,8 @@ function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $p
 
 	global $config, $snmp_error;
 
-	$max_oids = 1;
+	$max_oids   = 1;
+	$snmp_error = '';
 
 	if (!cacti_snmp_options_sanitize($version, $community, $port, $timeout, $retries, $max_oids)) {
 		return 'U';
@@ -244,7 +263,13 @@ function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $p
 			$snmp_value = snmp2_get($hostname . ':' . $port, $community, $oid, ($timeout * 1000), $retries);
 		} else {
 			if ($priv_proto == '[None]' || $priv_pass == '') {
-				$sec_level = 'authNoPriv';
+				if ($password == '') {
+					$sec_level   = 'noAuthNoPriv';
+					$sec_details = '';
+				} else {
+					$sec_level   = 'authNoPriv';
+					$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+				}
 				$priv_proto = '';
 			} else {
 				$sec_level = 'authPriv';
@@ -270,7 +295,13 @@ function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $p
 			$version = '2c'; /* ucd/net snmp prefers this over '2' */
 		} elseif ($version == '3') {
 			if ($priv_proto == '[None]' || $priv_pass == '') {
-				$sec_level = 'authNoPriv';
+				if ($password == '') {
+					$sec_level   = 'noAuthNoPriv';
+					$sec_details = '';
+				} else {
+					$sec_level   = 'authNoPriv';
+					$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+				}
 				$priv_proto = '';
 			} else {
 				$sec_level = 'authPriv';
@@ -296,8 +327,7 @@ function cacti_snmp_get_raw($hostname, $community, $oid, $version, $username, $p
 
 			$snmp_auth = trim('-u ' . snmp_escape_string($username) .
 				' -l ' . snmp_escape_string($sec_level) .
-				' -a ' . snmp_escape_string($auth_proto) .
-				' -A ' . snmp_escape_string($password) .
+				' '    . $sec_details .
 				' '    . $priv_pass .
 				' '    . $context .
 				' '    . $engineid);
@@ -335,7 +365,8 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 
 	global $config, $snmp_error;
 
-	$max_oids = 1;
+	$max_oids   = 1;
+	$snmp_error = '';
 
 	if (!cacti_snmp_options_sanitize($version, $community, $port, $timeout, $retries, $max_oids)) {
 		return 'U';
@@ -352,7 +383,13 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 			$snmp_value = snmp2_getnext($hostname . ':' . $port, $community, $oid, ($timeout * 1000), $retries);
 		} else {
 			if ($priv_proto == '[None]' || $priv_pass == '') {
-				$sec_level = 'authNoPriv';
+				if ($password == '') {
+					$sec_level   = 'noAuthNoPriv';
+					$sec_details = '';
+				} else {
+					$sec_level   = 'authNoPriv';
+					$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+				}
 				$priv_proto = '';
 			} else {
 				$sec_level = 'authPriv';
@@ -380,7 +417,13 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 			$version = '2c'; /* ucd/net snmp prefers this over '2' */
 		} elseif ($version == '3') {
 			if ($priv_proto == '[None]' || $priv_pass == '') {
-				$sec_level = 'authNoPriv';
+				if ($password == '') {
+					$sec_level   = 'noAuthNoPriv';
+					$sec_details = '';
+				} else {
+					$sec_level   = 'authNoPriv';
+					$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+				}
 				$priv_proto = '';
 			} else {
 				$sec_level = 'authPriv';
@@ -406,8 +449,7 @@ function cacti_snmp_getnext($hostname, $community, $oid, $version, $username, $p
 
 			$snmp_auth = trim('-u ' . snmp_escape_string($username) .
 				' -l ' . snmp_escape_string($sec_level) .
-				' -a ' . snmp_escape_string($auth_proto) .
-				' -A ' . snmp_escape_string($password) .
+				' '    . $sec_details .
 				' '    . $priv_pass .
 				' '    . $context .
 				' '    . $engineid);
@@ -567,6 +609,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 
 	global $config, $banned_snmp_strings, $snmp_error;
 
+	$snmp_error        = '';
 	$snmp_oid_included = true;
 	$snmp_auth	       = '';
 	$snmp_array        = array();
@@ -597,7 +640,13 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 			$temp_array = snmp2_real_walk($hostname . ':' . $port, $community, $oid, ($timeout * 1000), $retries);
 		} else {
 			if ($priv_proto == '[None]' || $priv_pass == '') {
-				$sec_level = 'authNoPriv';
+				if ($password == '') {
+					$sec_level   = 'noAuthNoPriv';
+					$sec_details = '';
+				} else {
+					$sec_level   = 'authNoPriv';
+					$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+				}
 				$priv_proto = '';
 			} else {
 				$sec_level = 'authPriv';
@@ -651,7 +700,13 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 			$version = '2c'; /* ucd/net snmp prefers this over '2' */
 		} elseif ($version == '3') {
 			if ($priv_proto == '[None]' || $priv_pass == '') {
-				$sec_level = 'authNoPriv';
+				if ($password == '') {
+					$sec_level   = 'noAuthNoPriv';
+					$sec_details = '';
+				} else {
+					$sec_level   = 'authNoPriv';
+					$sec_details = ' -a ' . snmp_escape_string($auth_proto) . ' -A ' . snmp_escape_string($password);
+				}
 				$priv_proto = '';
 			} else {
 				$sec_level = 'authPriv';
@@ -677,8 +732,7 @@ function cacti_snmp_walk($hostname, $community, $oid, $version, $username, $pass
 
 			$snmp_auth = trim('-u ' . snmp_escape_string($username) .
 				' -l ' . snmp_escape_string($sec_level) .
-				' -a ' . snmp_escape_string($auth_proto) .
-				' -A ' . snmp_escape_string($password) .
+				' '    . $sec_details .
 				' '    . $priv_pass .
 				' '    . $context .
 				' '    . $engineid);
