@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -40,6 +40,10 @@ switch (get_request_var('action')) {
 		ini_set('max_execution_time', $max_execution);
 		header('Location: utilities.php?action=view_poller_cache');exit;
 		break;
+	case 'rebuild_resource_cache':
+		rebuild_resource_cache();
+		header('Location: utilities.php?header=false');exit;
+		break;
 	case 'view_snmp_cache':
 		top_header();
 		utilities_view_snmp_cache();
@@ -122,6 +126,15 @@ switch (get_request_var('action')) {
     Utilities Functions
    ----------------------- */
 
+function rebuild_resource_cache() {
+	db_execute('DELETE FROM settings WHERE name LIKE "md5dirsum%"');
+	db_execute('TRUNCATE TABLE poller_resource_cache');
+
+	raise_message('resource_cache_rebuild');
+
+	cacti_log('NOTE: Poller Resource Cache scheduled for rebuild by user ' . get_username($_SESSION['sess_user_id']), false, 'WEBUI');
+}
+
 function utilities_view_tech($php_info = '') {
 	global $database_default, $config, $rrdtool_versions, $poller_options, $input_types;
 
@@ -164,10 +177,10 @@ function utilities_view_tech($php_info = '') {
 		$snmp_version = "<span class='deviceDown'>" . __('NET-SNMP Not Installed or its paths are not set.  Please install if you wish to monitor SNMP enabled devices.') . "</span>";
 	}
 
-	/* Check RRDTool issues */
+	/* Check RRDtool issues */
 	$rrdtool_error = '';
 	if ($rrdtool_version != read_config_option('rrdtool_version')) {
-		$rrdtool_error .= "<br><span class='deviceDown'>" . __('ERROR: Installed RRDtool version does not match configured version.<br>Please visit the %s and select the correct RRDtool Utility Version.', "<a href='" . htmlspecialchars('settings.php?tab=general') . "'>" . __('Configuration Settings') . '</a>') . "</span><br>";
+		$rrdtool_error .= "<br><span class='deviceDown'>" . __('ERROR: Installed RRDtool version does not match configured version.<br>Please visit the %s and select the correct RRDtool Utility Version.', "<a href='" . html_escape('settings.php?tab=general') . "'>" . __('Configuration Settings') . '</a>') . "</span><br>";
 	}
 	$graph_gif_count = db_fetch_cell('SELECT COUNT(*) FROM graph_templates_graph WHERE image_format_id = 2');
 	if ($graph_gif_count > 0) {
@@ -209,7 +222,7 @@ function utilities_view_tech($php_info = '') {
 
 		foreach (array_keys($tabs) as $tab_short_name) {
 			print "<li class='subTab'><a class='tab" . (($tab_short_name == $current_tab) ? " selected'" : "'") .
-				" href='" . htmlspecialchars($config['url_path'] .
+				" href='" . html_escape($config['url_path'] .
 				'utilities.php?action=view_tech' .
 				'&tab=' . $tab_short_name) .
 				"'>" . $tabs[$tab_short_name] . "</a></li>\n";
@@ -665,7 +678,7 @@ function utilities_view_user_log() {
 							<?php
 							if (sizeof($item_rows)) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
@@ -866,6 +879,7 @@ function utilities_view_logfile() {
 	global $log_tail_lines, $page_refresh_interval, $config;
 
 	$logfile = read_config_option('path_cactilog');
+	$logbase = basename($logfile);
 
 	if (isset_request_var('filename')) {
 		$requestedFile = dirname($logfile) . '/' . basename(get_nfilter_request_var('filename'));
@@ -880,6 +894,14 @@ function utilities_view_logfile() {
 		$logfile = $config['base_path'] . '/log/cacti.log';
 	}
 
+	if (get_nfilter_request_var('filename') != '') {
+		if (strpos(get_nfilter_request_var('filename'), $logbase) === false) {
+			raise_message('clog_invalid');
+			header('Location: utilities.php?action=view_logfile&filename=' . $logbase);
+			exit(0);
+		}
+	}
+
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'page' => array(
@@ -887,28 +909,26 @@ function utilities_view_logfile() {
 			'default' => '1'
 			),
 		'tail_lines' => array(
-			'filter' => FILTER_VALIDATE_INT,
+			'filter'  => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'rfilter' => array(
-			'filter' => FILTER_VALIDATE_IS_REGEX,
+			'filter'  => FILTER_VALIDATE_IS_REGEX,
 			'pageset' => true,
 			'default' => ''
 			),
 		'message_type' => array(
-			'filter' => FILTER_VALIDATE_INT,
+			'filter'  => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'reverse' => array(
-			'filter' => FILTER_VALIDATE_INT,
-			'pageset' => true,
+			'filter'  => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'refresh' => array(
-			'filter' => FILTER_VALIDATE_INT,
-			'pageset' => true,
+			'filter'  => FILTER_VALIDATE_INT,
 			'default' => read_config_option('log_refresh_interval')
 			)
 	);
@@ -935,7 +955,7 @@ function utilities_view_logfile() {
 	<script type='text/javascript'>
 
 	function purgeLog() {
-		strURL = urlPath+'utilities.php?action=purge_logfile&header=false';
+		strURL = urlPath+'utilities.php?action=purge_logfile&header=false&filename='+$('#filename').val();
 		loadPageNoHeader(strURL);
 	}
 
@@ -992,10 +1012,17 @@ function utilities_view_logfile() {
 						<?php print __('File');?>
 					</td>
 					<td>
-						<select id='filename' name='filename'>
+						<select id='filename'>
 							<?php
-							$selectedFile = basename(get_nfilter_request_var('filename'));
-							$logPath      = dirname(read_config_option('path_cactilog'));
+							$configLogPath = read_config_option('path_cactilog');
+							$configLogBase = basename($configLogPath);
+							$selectedFile  = basename(get_nfilter_request_var('filename'));
+
+							if ($configLogPath == '') {
+								$logPath = $config['base_path'] . '/log/';
+							} else {
+								$logPath = dirname($configLogPath);
+							}
 
 							if (is_readable($logPath)) {
 								$files = scandir($logPath);
@@ -1003,17 +1030,24 @@ function utilities_view_logfile() {
 								$files = array('cacti.log');
 							}
 
-							foreach($files as $logFile) {
-								if (in_array($logFile, array('.', '..', '.htaccess'))) {
-									continue;
-								}
+							if (sizeof($files)) {
+								foreach($files as $logFile) {
+									if (in_array($logFile, array('.', '..', '.htaccess'))) {
+										continue;
+									}
 
-								print "<option value='" . $logFile . "'";
-								if ($selectedFile == $logFile) {
-									print ' selected';
-								}
+									if (strpos($logFile, $configLogBase) === false) {
+										continue;
+									}
 
-								print '>' . $logFile . "</option>\n";
+									print "<option value='" . $logFile . "'";
+
+									if ($selectedFile == $logFile) {
+										print ' selected';
+									}
+
+									print '>' . $logFile . "</option>\n";
+								}
 							}
 							?>
 						</select>
@@ -1130,13 +1164,13 @@ function utilities_view_logfile() {
 		$ds_start   = strpos($item, 'DS[');
 
 		if (!$host_start && !$ds_start) {
-			$new_item = cacti_htmlspecialchars($item);
+			$new_item = html_escape($item);
 		} else {
 			$new_item = '';
 			while ($host_start) {
 				$host_end   = strpos($item, ']', $host_start);
 				$host_id    = substr($item, $host_start + 7, $host_end - ($host_start + 7));
-				$new_item  .= cacti_htmlspecialchars(substr($item, 0, $host_start + 7)) . "<a href='" . cacti_htmlspecialchars('host.php?action=edit&id=' . $host_id) . "'>" . cacti_htmlspecialchars(substr($item, $host_start + 7, $host_end - ($host_start + 7))) . '</a>';
+				$new_item  .= html_escape(substr($item, 0, $host_start + 7)) . "<a href='" . html_escape('host.php?action=edit&id=' . $host_id) . "'>" . html_escape(substr($item, $host_start + 7, $host_end - ($host_start + 7))) . '</a>';
 				$item       = substr($item, $host_end);
 				$host_start = strpos($item, 'Device[');
 			}
@@ -1145,12 +1179,12 @@ function utilities_view_logfile() {
 			while ($ds_start) {
 				$ds_end    = strpos($item, ']', $ds_start);
 				$ds_id     = substr($item, $ds_start + 3, $ds_end - ($ds_start + 3));
-				$new_item .= cacti_htmlspecialchars(substr($item, 0, $ds_start + 3)) . "<a href='" . cacti_htmlspecialchars('data_sources.php?action=ds_edit&id=' . $ds_id) . "'>" . cacti_htmlspecialchars(substr($item, $ds_start + 3, $ds_end - ($ds_start + 3))) . '</a>';
+				$new_item .= html_escape(substr($item, 0, $ds_start + 3)) . "<a href='" . html_escape('data_sources.php?action=ds_edit&id=' . $ds_id) . "'>" . html_escape(substr($item, $ds_start + 3, $ds_end - ($ds_start + 3))) . '</a>';
 				$item      = substr($item, $ds_end);
 				$ds_start  = strpos($item, 'DS[');
 			}
 
-			$new_item .= cacti_htmlspecialchars($item);
+			$new_item .= html_escape($item);
 		}
 
 		/* get the background color */
@@ -1348,7 +1382,7 @@ function utilities_view_snmp_cache() {
 
 							if (sizeof($snmp_queries)) {
 								foreach ($snmp_queries as $snmp_query) {
-									print "<option value='" . $snmp_query['id'] . "'"; if (get_request_var('snmp_query_id') == $snmp_query['id']) { print ' selected'; } print '>' . htmlspecialchars($snmp_query['name'], ENT_QUOTES) . "</option>\n";
+									print "<option value='" . $snmp_query['id'] . "'"; if (get_request_var('snmp_query_id') == $snmp_query['id']) { print ' selected'; } print '>' . html_escape($snmp_query['name']) . "</option>\n";
 								}
 							}
 							?>
@@ -1363,7 +1397,7 @@ function utilities_view_snmp_cache() {
 							<?php
 							if (sizeof($item_rows)) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
@@ -1608,7 +1642,7 @@ function utilities_view_poller_cache() {
 
 							if (sizeof($templates)) {
 								foreach ($templates as $template) {
-									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . title_trim(htmlspecialchars($template['name']), 40) . "</option>\n";
+									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . title_trim(html_escape($template['name']), 40) . "</option>\n";
 								}
 							}
 							?>
@@ -1650,7 +1684,7 @@ function utilities_view_poller_cache() {
 							<?php
 							if (sizeof($item_rows)) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
@@ -1825,7 +1859,11 @@ function utilities() {
 		),
 		__('Rebuild Poller Cache') => array(
 			'link'  => 'utilities.php?action=clear_poller_cache',
-			'description' => __('The Poller Cache will be re-generated if you select this option. Use this option only in the event of a database crash if you are experiencing issues after the crash and have already run the database repair tools.  Alternatively, if you are having problems with a specific Device, simply re-save that Device to rebuild its Poller Cache.  There is also a command line interface equivalent to this command that is recommended for large systems.  <i class="deviceDown">NOTE: On large systems, this command may take several minutes to hours to complete and therefore should not be run from the Cacti UI.</i>')
+			'description' => __('The Poller Cache will be re-generated if you select this option. Use this option only in the event of a database crash if you are experiencing issues after the crash and have already run the database repair tools.  Alternatively, if you are having problems with a specific Device, simply re-save that Device to rebuild its Poller Cache.  There is also a command line interface equivalent to this command that is recommended for large systems.  <i class="deviceDown">NOTE: On large systems, this command may take several minutes to hours to complete and therefore should not be run from the Cacti UI.  You can simply run \'php -q cli/rebuild_poller_cache.php --help\' at the command line for more information.</i>')
+		),
+		__('Rebuild Resource Cache') => array(
+			'link'  => 'utilities.php?action=rebuild_resource_cache',
+			'description' => __('When operating multiple Data Collectors in Cacti, Cacti will attempt to maintain state for key files on all Data Collectors.  This includes all core, non-install related website and plugin files.  When you force a Resource Cache rebild, Cacti will clear the local Resource Cache, and then rebuild it at the next scheduled poller start.  This will trigger all Remote Data Collectors to recheck their website and plugin files for consistency.')
 		),
 	);
 
@@ -1871,7 +1909,7 @@ function utilities() {
 		foreach($content as $title => $details) {
 			form_alternate_row();
 			print "<td class='nowrap' style='vertical-align:top;'>";
-			print "<a class='hyperLink' href='" . htmlspecialchars($details['link']) . "'>" . $title . "</a>";
+			print "<a class='hyperLink' href='" . html_escape($details['link']) . "'>" . $title . "</a>";
 			print "</td>\n";
 			print "<td>";
 			print $details['description'];
@@ -1894,17 +1932,17 @@ function boost_display_run_status() {
 
 	load_current_session_value('refresh', 'sess_boost_utilities_refresh', '30');
 
-	$last_run_time   = read_config_option('boost_last_run_time', TRUE);
-	$next_run_time   = read_config_option('boost_next_run_time', TRUE);
+	$last_run_time   = read_config_option('boost_last_run_time', true);
+	$next_run_time   = read_config_option('boost_next_run_time', true);
 
-	$rrd_updates     = read_config_option('boost_rrd_update_enable', TRUE);
-	$boost_cache     = read_config_option('boost_png_cache_enable', TRUE);
+	$rrd_updates     = read_config_option('boost_rrd_update_enable', true);
+	$boost_cache     = read_config_option('boost_png_cache_enable', true);
 
-	$max_records     = read_config_option('boost_rrd_update_max_records', TRUE);
-	$max_runtime     = read_config_option('boost_rrd_update_max_runtime', TRUE);
-	$update_interval = read_config_option('boost_rrd_update_interval', TRUE);
-	$peak_memory     = read_config_option('boost_peak_memory', TRUE);
-	$detail_stats    = read_config_option('stats_detail_boost', TRUE);
+	$max_records     = read_config_option('boost_rrd_update_max_records', true);
+	$max_runtime     = read_config_option('boost_rrd_update_max_runtime', true);
+	$update_interval = read_config_option('boost_rrd_update_interval', true);
+	$peak_memory     = read_config_option('boost_peak_memory', true);
+	$detail_stats    = read_config_option('stats_detail_boost', true);
 
 	$refresh['seconds'] = get_request_var('refresh');
 	$refresh['page']    = 'utilities.php?action=view_boost_status&header=false';
@@ -1980,7 +2018,7 @@ function boost_display_run_status() {
 
 	$total_data_sources = db_fetch_cell('SELECT COUNT(*) FROM poller_item');
 
-	$boost_status = read_config_option('boost_poller_status', TRUE);
+	$boost_status = read_config_option('boost_poller_status', true);
 	if ($boost_status != '') {
 		$boost_status_array = explode(':', $boost_status);
 
@@ -1996,7 +2034,7 @@ function boost_display_run_status() {
 		$boost_status_date = '';
 	}
 
-	$stats_boost = read_config_option('stats_boost', TRUE);
+	$stats_boost = read_config_option('stats_boost', true);
 	if ($stats_boost != '') {
 		$stats_boost_array = explode(' ', $stats_boost);
 
@@ -2011,13 +2049,13 @@ function boost_display_run_status() {
 	}
 
 	/* get cache directory size/contents */
-	$cache_directory    = read_config_option('boost_png_cache_directory', TRUE);
+	$cache_directory    = read_config_option('boost_png_cache_directory', true);
 	$directory_contents = array();
 
 	if (is_dir($cache_directory)) {
 		if ($handle = @opendir($cache_directory)) {
 			/* This is the correct way to loop over the directory. */
-			while (FALSE !== ($file = readdir($handle))) {
+			while (false !== ($file = readdir($handle))) {
 				$directory_contents[] = $file;
 			}
 
@@ -2095,12 +2133,12 @@ function boost_display_run_status() {
 	if ($output_length != '') {
 		$parts = explode(':', $output_length);
 		if ((time()-1200) > $parts[0]) {
-			$ref = TRUE;
+			$ref = true;
 		} else {
-			$ref = FALSE;
+			$ref = false;
 		}
 	} else {
-		$ref = TRUE;
+		$ref = true;
 	}
 
 	if ($ref) {
@@ -2142,8 +2180,13 @@ function boost_display_run_status() {
 
 	form_alternate_row();
 	print '<td class="utilityPick">' . __('Last Run Duration:') . '</td><td>';
-	print (($boost_last_run_duration > 60) ? __('%d minutes', (int)($boost_last_run_duration/60)) : '' ) . __('%d seconds', $boost_last_run_duration%60);
-	if ($rrd_updates != ''){ print ' (' . __('%0.2f percent of update frequency)', round(100*$boost_last_run_duration/$update_interval/60));}
+
+	if (is_numeric($boost_last_run_duration)) {
+		print (($boost_last_run_duration > 60) ? __('%d minutes', (int)($boost_last_run_duration/60)) : '' ) . __('%d seconds', $boost_last_run_duration%60);
+		if ($rrd_updates != ''){ print ' (' . __('%0.2f percent of update frequency)', round(100*$boost_last_run_duration/$update_interval/60));}
+	} else {
+		print __('N/A');
+	}
 	print '</td>';
 
 	form_alternate_row();
@@ -2188,7 +2231,7 @@ function boost_display_run_status() {
 	form_alternate_row();
 	print '<td>' . __('Cached Files Size:') . '</td><td>' . $directory_size . '</td>';
 
-	html_end_box(TRUE);
+	html_end_box(true);
 }
 
 /**
@@ -2305,7 +2348,7 @@ function snmpagent_utilities_run_cache() {
 								<?php
 								if (sizeof($mibs) > 0) {
 									foreach ($mibs as $mib) {
-										print "<option value='" . $mib['mib'] . "'"; if (get_request_var('mib') == $mib['mib']) { print ' selected'; } print '>' . htmlspecialchars($mib['mib'], ENT_QUOTES) . "</option>\n";
+										print "<option value='" . $mib['mib'] . "'"; if (get_request_var('mib') == $mib['mib']) { print ' selected'; } print '>' . html_escape($mib['mib']) . "</option>\n";
 									}
 								}
 								?>
@@ -2320,7 +2363,7 @@ function snmpagent_utilities_run_cache() {
 								<?php
 								if (sizeof($item_rows)) {
 									foreach ($item_rows as $key => $value) {
-										print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+										print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 									}
 								}
 								?>
@@ -2384,7 +2427,7 @@ function snmpagent_utilities_run_cache() {
 			form_alternate_row('line' . $item['oid'], false);
 			form_selectable_cell( $oid, $item['oid']);
 			if($item['description']) {
-				print '<td><a href="#" title="<div class=\'header\'>' . $name . '</div><div class=\'content preformatted\'>' . htmlspecialchars($item['description'], ENT_QUOTES) . '</div>" class="tooltip">' . $name . '</a></td>';
+				print '<td><a href="#" title="<div class=\'header\'>' . $name . '</div><div class=\'content preformatted\'>' . html_escape($item['description']) . '</div>" class="tooltip">' . $name . '</a></td>';
 			}else {
 				print "<td>$name</td>";
 			}
@@ -2555,7 +2598,7 @@ function snmpagent_utilities_run_eventlog(){
 								<option value='-1'<?php if (get_request_var('severity') == '-1') {?> selected<?php }?>><?php print __('Any');?></option>
 								<?php
 								foreach ($severity_levels as $level => $name) {
-									print "<option value='" . $level . "'"; if (get_request_var('severity') == $level) { print ' selected'; } print '>' . htmlspecialchars($name, ENT_QUOTES) . "</option>\n";
+									print "<option value='" . $level . "'"; if (get_request_var('severity') == $level) { print ' selected'; } print '>' . html_escape($name) . "</option>\n";
 								}
 								?>
 							</select>
@@ -2582,7 +2625,7 @@ function snmpagent_utilities_run_eventlog(){
 								<?php
 								if (sizeof($item_rows)) {
 									foreach ($item_rows as $key => $value) {
-										print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+										print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 									}
 								}
 								?>
@@ -2655,12 +2698,12 @@ function snmpagent_utilities_run_eventlog(){
 
 			print "<td title='" . __esc('Severity Level: %s', $severity_levels[$item['severity']]) . "' style='width:10px;background-color: " . $severity_colors[$item['severity']] . ";border-top:1px solid white;border-bottom:1px solid white;'></td>";
 			print "<td class='nowrap'>" . date('Y-m-d H:i:s', $item['time']) . '</td>';
-			print '<td>' . htmlspecialchars($item['hostname'], ENT_QUOTES) . '</td>';
+			print '<td>' . html_escape($item['hostname']) . '</td>';
 
 			if($item['description']) {
-				print '<td><a href="#" title="<div class=\'header\'>' . htmlspecialchars($item['notification'], ENT_QUOTES) . '</div><div class=\'content preformatted\'>' . htmlspecialchars($item['description'], ENT_QUOTES) . '</div>" class="tooltip">' . htmlspecialchars($item['notification']) . '</a></td>';
+				print '<td><a href="#" title="<div class=\'header\'>' . html_escape($item['notification']) . '</div><div class=\'content preformatted\'>' . html_escape($item['description']) . '</div>" class="tooltip">' . html_escape($item['notification']) . '</a></td>';
 			}else {
-				print '<td>' . htmlspecialchars($item['notification']) . '</td>';
+				print '<td>' . html_escape($item['notification']) . '</td>';
 			}
 
 			print "<td>$varbinds</td>";
